@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -36,7 +14,10 @@ class LANGUAGESERVERPROTOCOL_EXPORT DynamicRegistrationCapabilities : public Jso
 public:
     using JsonObject::JsonObject;
 
-    Utils::optional<bool> dynamicRegistration() const { return optionalValue<bool>(dynamicRegistrationKey); }
+    std::optional<bool> dynamicRegistration() const
+    {
+        return optionalValue<bool>(dynamicRegistrationKey);
+    }
     void setDynamicRegistration(bool dynamicRegistration) { insert(dynamicRegistrationKey, dynamicRegistration); }
     void clearDynamicRegistration() { remove(dynamicRegistrationKey); }
 };
@@ -50,7 +31,7 @@ public:
       * The client will send the `textDocument/semanticTokens/full/delta`
       * request if the server provides a corresponding handler.
       */
-    Utils::optional<bool> delta() const { return optionalValue<bool>(deltaKey); }
+    std::optional<bool> delta() const { return optionalValue<bool>(deltaKey); }
     void setDelta(bool delta) { insert(deltaKey, delta); }
     void clearDelta() { remove(deltaKey); }
 };
@@ -78,16 +59,16 @@ public:
          * The client will send the `textDocument/semanticTokens/range` request
          * if the server provides a corresponding handler.
          */
-        Utils::optional<Utils::variant<bool, QJsonObject>> range() const;
-        void setRange(const Utils::variant<bool, QJsonObject> &range);
+        std::optional<std::variant<bool, QJsonObject>> range() const;
+        void setRange(const std::variant<bool, QJsonObject> &range);
         void clearRange() { remove(rangeKey); }
 
         /**
          * The client will send the `textDocument/semanticTokens/full` request
          * if the server provides a corresponding handler.
          */
-        Utils::optional<Utils::variant<bool, FullSemanticTokenOptions>> full() const;
-        void setFull(const Utils::variant<bool, FullSemanticTokenOptions> &full);
+        std::optional<std::variant<bool, FullSemanticTokenOptions>> full() const;
+        void setFull(const std::variant<bool, FullSemanticTokenOptions> &full);
         void clearFull() { remove(fullKey); }
     };
 
@@ -107,12 +88,18 @@ public:
     void setFormats(const QList<QString> &value) { insertArray(formatsKey, value); }
 
     /// Whether the client supports tokens that can overlap each other.
-    Utils::optional<bool> overlappingTokenSupport() const { return optionalValue<bool>(overlappingTokenSupportKey); }
+    std::optional<bool> overlappingTokenSupport() const
+    {
+        return optionalValue<bool>(overlappingTokenSupportKey);
+    }
     void setOverlappingTokenSupport(bool overlappingTokenSupport) { insert(overlappingTokenSupportKey, overlappingTokenSupport); }
     void clearOverlappingTokenSupport() { remove(overlappingTokenSupportKey); }
 
     /// Whether the client supports tokens that can span multiple lines.
-    Utils::optional<bool> multiLineTokenSupport() const { return optionalValue<bool>(multiLineTokenSupportKey); }
+    std::optional<bool> multiLineTokenSupport() const
+    {
+        return optionalValue<bool>(multiLineTokenSupportKey);
+    }
     void setMultiLineTokenSupport(bool multiLineTokenSupport) { insert(multiLineTokenSupportKey, multiLineTokenSupport); }
     void clearMultiLineTokenSupport() { remove(multiLineTokenSupportKey); }
 
@@ -139,18 +126,18 @@ public:
          * the symbol kinds from `File` to `Array` as defined in
          * the initial version of the protocol.
          */
-        Utils::optional<QList<SymbolKind>> valueSet() const;
+        std::optional<QList<SymbolKind>> valueSet() const;
         void setValueSet(const QList<SymbolKind> &valueSet);
         void clearValueSet() { remove(valueSetKey); }
     };
 
     // Specific capabilities for the `SymbolKind` in the `workspace/symbol` request.
-    Utils::optional<SymbolKindCapabilities> symbolKind() const
+    std::optional<SymbolKindCapabilities> symbolKind() const
     { return optionalValue<SymbolKindCapabilities>(symbolKindKey); }
     void setSymbolKind(const SymbolKindCapabilities &symbolKind) { insert(symbolKindKey, symbolKind); }
     void clearSymbolKind() { remove(symbolKindKey); }
 
-    Utils::optional<bool> hierarchicalDocumentSymbolSupport() const
+    std::optional<bool> hierarchicalDocumentSymbolSupport() const
     { return optionalValue<bool>(hierarchicalDocumentSymbolSupportKey); }
     void setHierarchicalDocumentSymbolSupport(bool hierarchicalDocumentSymbolSupport)
     { insert(hierarchicalDocumentSymbolSupportKey, hierarchicalDocumentSymbolSupport); }
@@ -168,7 +155,7 @@ public:
         using DynamicRegistrationCapabilities::DynamicRegistrationCapabilities;
 
         // The client supports sending will save notifications.
-        Utils::optional<bool> willSave() const { return optionalValue<bool>(willSaveKey); }
+        std::optional<bool> willSave() const { return optionalValue<bool>(willSaveKey); }
         void setWillSave(bool willSave) { insert(willSaveKey, willSave); }
         void clearWillSave() { remove(willSaveKey); }
 
@@ -177,19 +164,19 @@ public:
          * waits for a response providing text edits which will
          * be applied to the document before it is saved.
          */
-        Utils::optional<bool> willSaveWaitUntil() const
+        std::optional<bool> willSaveWaitUntil() const
         { return optionalValue<bool>(willSaveWaitUntilKey); }
         void setWillSaveWaitUntil(bool willSaveWaitUntil)
         { insert(willSaveWaitUntilKey, willSaveWaitUntil); }
         void clearWillSaveWaitUntil() { remove(willSaveWaitUntilKey); }
 
         // The client supports did save notifications.
-        Utils::optional<bool> didSave() const { return optionalValue<bool>(didSaveKey); }
+        std::optional<bool> didSave() const { return optionalValue<bool>(didSaveKey); }
         void setDidSave(bool didSave) { insert(didSaveKey, didSave); }
         void clearDidSave() { remove(didSaveKey); }
     };
 
-    Utils::optional<SynchronizationCapabilities> synchronization() const
+    std::optional<SynchronizationCapabilities> synchronization() const
     { return optionalValue<SynchronizationCapabilities>(synchronizationKey); }
     void setSynchronization(const SynchronizationCapabilities &synchronization)
     { insert(synchronizationKey, synchronization); }
@@ -213,14 +200,14 @@ public:
              * the end of the snippet. Placeholders with equal identifiers are linked,
              * that is typing in one will update others too.
              */
-            Utils::optional<bool> snippetSupport() const
+            std::optional<bool> snippetSupport() const
             { return optionalValue<bool>(snippetSupportKey); }
             void setSnippetSupport(bool snippetSupport)
             { insert(snippetSupportKey, snippetSupport); }
             void clearSnippetSupport() { remove(snippetSupportKey); }
 
             // Client supports commit characters on a completion item.
-            Utils::optional<bool> commitCharacterSupport() const
+            std::optional<bool> commitCharacterSupport() const
             { return optionalValue<bool>(commitCharacterSupportKey); }
             void setCommitCharacterSupport(bool commitCharacterSupport)
             { insert(commitCharacterSupportKey, commitCharacterSupport); }
@@ -230,13 +217,13 @@ public:
              * Client supports the follow content formats for the documentation
              * property. The order describes the preferred format of the client.
              */
-            Utils::optional<QList<MarkupKind>> documentationFormat() const;
+            std::optional<QList<MarkupKind>> documentationFormat() const;
             void setDocumentationFormat(const QList<MarkupKind> &documentationFormat);
             void clearDocumentationFormat() { remove(documentationFormatKey); }
         };
 
         // The client supports the following `CompletionItem` specific capabilities.
-        Utils::optional<CompletionItemCapbilities> completionItem() const
+        std::optional<CompletionItemCapbilities> completionItem() const
         { return optionalValue<CompletionItemCapbilities>(completionItemKey); }
         void setCompletionItem(const CompletionItemCapbilities &completionItem)
         { insert(completionItemKey, completionItem); }
@@ -257,12 +244,12 @@ public:
              * the completion items kinds from `Text` to `Reference` as defined in
              * the initial version of the protocol.
              */
-            Utils::optional<QList<CompletionItemKind::Kind>> valueSet() const;
+            std::optional<QList<CompletionItemKind::Kind>> valueSet() const;
             void setValueSet(const QList<CompletionItemKind::Kind> &valueSet);
             void clearValueSet() { remove(valueSetKey); }
         };
 
-        Utils::optional<CompletionItemKindCapabilities> completionItemKind() const
+        std::optional<CompletionItemKindCapabilities> completionItemKind() const
         { return optionalValue<CompletionItemKindCapabilities>(completionItemKindKey); }
         void setCompletionItemKind(const CompletionItemKindCapabilities &completionItemKind)
         { insert(completionItemKindKey, completionItemKind); }
@@ -272,13 +259,16 @@ public:
          * The client supports to send additional context information for a
          * `textDocument/completion` request.
          */
-        Utils::optional<bool> contextSupport() const { return optionalValue<bool>(contextSupportKey); }
+        std::optional<bool> contextSupport() const
+        {
+            return optionalValue<bool>(contextSupportKey);
+        }
         void setContextSupport(bool contextSupport) { insert(contextSupportKey, contextSupport); }
         void clearContextSupport() { remove(contextSupportKey); }
     };
 
     // Capabilities specific to the `textDocument/completion`
-    Utils::optional<CompletionCapabilities> completion() const
+    std::optional<CompletionCapabilities> completion() const
     { return optionalValue<CompletionCapabilities>(completionKey); }
     void setCompletion(const CompletionCapabilities &completion)
     { insert(completionKey, completion); }
@@ -292,12 +282,15 @@ public:
          * Client supports the follow content formats for the content
          * property. The order describes the preferred format of the client.
          */
-        Utils::optional<QList<MarkupKind>> contentFormat() const;
+        std::optional<QList<MarkupKind>> contentFormat() const;
         void setContentFormat(const QList<MarkupKind> &contentFormat);
         void clearContentFormat() { remove(contentFormatKey); }
     };
 
-    Utils::optional<HoverCapabilities> hover() const { return optionalValue<HoverCapabilities>(hoverKey); }
+    std::optional<HoverCapabilities> hover() const
+    {
+        return optionalValue<HoverCapabilities>(hoverKey);
+    }
     void setHover(const HoverCapabilities &hover) { insert(hoverKey, hover); }
     void clearHover() { remove(hoverKey); }
 
@@ -314,11 +307,11 @@ public:
              * Client supports the follow content formats for the documentation
              * property. The order describes the preferred format of the client.
              */
-            Utils::optional<QList<MarkupKind>> documentationFormat() const;
+            std::optional<QList<MarkupKind>> documentationFormat() const;
             void setDocumentationFormat(const QList<MarkupKind> &documentationFormat);
             void clearDocumentationFormat() { remove(documentationFormatKey); }
 
-            Utils::optional<bool> activeParameterSupport() const
+            std::optional<bool> activeParameterSupport() const
             { return optionalValue<bool>(activeParameterSupportKey); }
             void setActiveParameterSupport(bool activeParameterSupport)
             { insert(activeParameterSupportKey, activeParameterSupport); }
@@ -326,7 +319,7 @@ public:
         };
 
         // The client supports the following `SignatureInformation` specific properties.
-        Utils::optional<SignatureInformationCapabilities> signatureInformation() const
+        std::optional<SignatureInformationCapabilities> signatureInformation() const
         { return optionalValue<SignatureInformationCapabilities>(signatureInformationKey); }
         void setSignatureInformation(const SignatureInformationCapabilities &signatureInformation)
         { insert(signatureInformationKey, signatureInformation); }
@@ -334,56 +327,56 @@ public:
     };
 
     // Capabilities specific to the `textDocument/signatureHelp`
-    Utils::optional<SignatureHelpCapabilities> signatureHelp() const
+    std::optional<SignatureHelpCapabilities> signatureHelp() const
     { return optionalValue<SignatureHelpCapabilities>(signatureHelpKey); }
     void setSignatureHelp(const SignatureHelpCapabilities &signatureHelp)
     { insert(signatureHelpKey, signatureHelp); }
     void clearSignatureHelp() { remove(signatureHelpKey); }
 
     // Whether references supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> references() const
+    std::optional<DynamicRegistrationCapabilities> references() const
     { return optionalValue<DynamicRegistrationCapabilities>(referencesKey); }
     void setReferences(const DynamicRegistrationCapabilities &references)
     { insert(referencesKey, references); }
     void clearReferences() { remove(referencesKey); }
 
     // Whether document highlight supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> documentHighlight() const
+    std::optional<DynamicRegistrationCapabilities> documentHighlight() const
     { return optionalValue<DynamicRegistrationCapabilities>(documentHighlightKey); }
     void setDocumentHighlight(const DynamicRegistrationCapabilities &documentHighlight)
     { insert(documentHighlightKey, documentHighlight); }
     void clearDocumentHighlight() { remove(documentHighlightKey); }
 
     // Capabilities specific to the `textDocument/documentSymbol`
-    Utils::optional<SymbolCapabilities> documentSymbol() const
+    std::optional<SymbolCapabilities> documentSymbol() const
     { return optionalValue<SymbolCapabilities>(documentSymbolKey); }
     void setDocumentSymbol(const SymbolCapabilities &documentSymbol)
     { insert(documentSymbolKey, documentSymbol); }
     void clearDocumentSymbol() { remove(documentSymbolKey); }
 
     // Whether formatting supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> formatting() const
+    std::optional<DynamicRegistrationCapabilities> formatting() const
     { return optionalValue<DynamicRegistrationCapabilities>(formattingKey); }
     void setFormatting(const DynamicRegistrationCapabilities &formatting)
     { insert(formattingKey, formatting); }
     void clearFormatting() { remove(formattingKey); }
 
     // Whether range formatting supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> rangeFormatting() const
+    std::optional<DynamicRegistrationCapabilities> rangeFormatting() const
     { return optionalValue<DynamicRegistrationCapabilities>(rangeFormattingKey); }
     void setRangeFormatting(const DynamicRegistrationCapabilities &rangeFormatting)
     { insert(rangeFormattingKey, rangeFormatting); }
     void clearRangeFormatting() { remove(rangeFormattingKey); }
 
     // Whether on type formatting supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> onTypeFormatting() const
+    std::optional<DynamicRegistrationCapabilities> onTypeFormatting() const
     { return optionalValue<DynamicRegistrationCapabilities>(onTypeFormattingKey); }
     void setOnTypeFormatting(const DynamicRegistrationCapabilities &onTypeFormatting)
     { insert(onTypeFormattingKey, onTypeFormatting); }
     void clearOnTypeFormatting() { remove(onTypeFormattingKey); }
 
     // Whether definition supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> definition() const
+    std::optional<DynamicRegistrationCapabilities> definition() const
     { return optionalValue<DynamicRegistrationCapabilities>(definitionKey); }
     void setDefinition(const DynamicRegistrationCapabilities &definition)
     { insert(definitionKey, definition); }
@@ -394,7 +387,7 @@ public:
      * the client supports the new `(TextDocumentRegistrationOptions & StaticRegistrationOptions)`
      * return value for the corresponding server capability as well.
      */
-    Utils::optional<DynamicRegistrationCapabilities> typeDefinition() const
+    std::optional<DynamicRegistrationCapabilities> typeDefinition() const
     { return optionalValue<DynamicRegistrationCapabilities>(typeDefinitionKey); }
     void setTypeDefinition(const DynamicRegistrationCapabilities &typeDefinition)
     { insert(typeDefinitionKey, typeDefinition); }
@@ -405,7 +398,7 @@ public:
      * the client supports the new `(TextDocumentRegistrationOptions & StaticRegistrationOptions)`
      * return value for the corresponding server capability as well.
      */
-    Utils::optional<DynamicRegistrationCapabilities> implementation() const
+    std::optional<DynamicRegistrationCapabilities> implementation() const
     { return optionalValue<DynamicRegistrationCapabilities>(implementationKey); }
     void setImplementation(const DynamicRegistrationCapabilities &implementation)
     { insert(implementationKey, implementation); }
@@ -443,7 +436,7 @@ public:
             bool isValid() const override { return contains(codeActionKindKey); }
         };
 
-        Utils::optional<CodeActionLiteralSupport> codeActionLiteralSupport() const
+        std::optional<CodeActionLiteralSupport> codeActionLiteralSupport() const
         { return optionalValue<CodeActionLiteralSupport>(codeActionLiteralSupportKey); }
         void setCodeActionLiteralSupport(const CodeActionLiteralSupport &codeActionLiteralSupport)
         { insert(codeActionLiteralSupportKey, codeActionLiteralSupport); }
@@ -451,21 +444,21 @@ public:
     };
 
     // Whether code action supports dynamic registration.
-    Utils::optional<CodeActionCapabilities> codeAction() const
+    std::optional<CodeActionCapabilities> codeAction() const
     { return optionalValue<CodeActionCapabilities>(codeActionKey); }
     void setCodeAction(const CodeActionCapabilities &codeAction)
     { insert(codeActionKey, codeAction); }
     void clearCodeAction() { remove(codeActionKey); }
 
     // Whether code lens supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> codeLens() const
+    std::optional<DynamicRegistrationCapabilities> codeLens() const
     { return optionalValue<DynamicRegistrationCapabilities>(codeLensKey); }
     void setCodeLens(const DynamicRegistrationCapabilities &codeLens)
     { insert(codeLensKey, codeLens); }
     void clearCodeLens() { remove(codeLensKey); }
 
     // Whether document link supports dynamic registration.
-    Utils::optional<DynamicRegistrationCapabilities> documentLink() const
+    std::optional<DynamicRegistrationCapabilities> documentLink() const
     { return optionalValue<DynamicRegistrationCapabilities>(documentLinkKey); }
     void setDocumentLink(const DynamicRegistrationCapabilities &documentLink)
     { insert(documentLinkKey, documentLink); }
@@ -476,7 +469,7 @@ public:
      * the client supports the new `(ColorProviderOptions & TextDocumentRegistrationOptions & StaticRegistrationOptions)`
      * return value for the corresponding server capability as well.
      */
-    Utils::optional<DynamicRegistrationCapabilities> colorProvider() const
+    std::optional<DynamicRegistrationCapabilities> colorProvider() const
     { return optionalValue<DynamicRegistrationCapabilities>(colorProviderKey); }
     void setColorProvider(const DynamicRegistrationCapabilities &colorProvider)
     { insert(colorProviderKey, colorProvider); }
@@ -493,21 +486,30 @@ public:
          * @since version 3.12.0
          */
 
-        Utils::optional<bool> prepareSupport() const { return optionalValue<bool>(prepareSupportKey); }
+        std::optional<bool> prepareSupport() const
+        {
+            return optionalValue<bool>(prepareSupportKey);
+        }
         void setPrepareSupport(bool prepareSupport) { insert(prepareSupportKey, prepareSupport); }
         void clearPrepareSupport() { remove(prepareSupportKey); }
     };
 
     // Whether rename supports dynamic registration.
-    Utils::optional<RenameClientCapabilities> rename() const
+    std::optional<RenameClientCapabilities> rename() const
     { return optionalValue<RenameClientCapabilities>(renameKey); }
     void setRename(const RenameClientCapabilities &rename)
     { insert(renameKey, rename); }
     void clearRename() { remove(renameKey); }
 
-    Utils::optional<SemanticTokensClientCapabilities> semanticTokens() const;
+    std::optional<SemanticTokensClientCapabilities> semanticTokens() const;
     void setSemanticTokens(const SemanticTokensClientCapabilities &semanticTokens);
     void clearSemanticTokens() { remove(semanticTokensKey); }
+
+    std::optional<DynamicRegistrationCapabilities> callHierarchy() const
+    { return optionalValue<DynamicRegistrationCapabilities>(callHierarchyKey); }
+    void setCallHierarchy(const DynamicRegistrationCapabilities &callHierarchy)
+    { insert(callHierarchyKey, callHierarchy); }
+    void clearCallHierarchy() { remove(callHierarchyKey); }
 };
 
 class LANGUAGESERVERPROTOCOL_EXPORT SemanticTokensWorkspaceClientCapabilities : public JsonObject
@@ -523,7 +525,7 @@ public:
      * and is useful for situation where a server for example detect a project
      * wide change that requires such a calculation.
      */
-    Utils::optional<bool> refreshSupport() const { return optionalValue<bool>(refreshSupportKey); }
+    std::optional<bool> refreshSupport() const { return optionalValue<bool>(refreshSupportKey); }
     void setRefreshSupport(bool refreshSupport) { insert(refreshSupportKey, refreshSupport); }
     void clearRefreshSupport() { remove(refreshSupportKey); }
 };
@@ -538,7 +540,7 @@ public:
      * The client supports applying batch edits to the workspace by supporting the request
      * 'workspace/applyEdit'
      */
-    Utils::optional<bool> applyEdit() const { return optionalValue<bool>(applyEditKey); }
+    std::optional<bool> applyEdit() const { return optionalValue<bool>(applyEditKey); }
     void setApplyEdit(bool applyEdit) { insert(applyEditKey, applyEdit); }
     void clearApplyEdit() { remove(applyEditKey); }
 
@@ -548,60 +550,68 @@ public:
         using JsonObject::JsonObject;
 
         // The client supports versioned document changes in `WorkspaceEdit`s
-        Utils::optional<bool> documentChanges() const
+        std::optional<bool> documentChanges() const
         { return optionalValue<bool>(documentChangesKey); }
         void setDocumentChanges(bool documentChanges)
         { insert(documentChangesKey, documentChanges); }
         void clearDocumentChanges() { remove(documentChangesKey); }
+
+        enum class ResourceOperationKind { Create, Rename, Delete };
+
+        // The resource operations the client supports. Clients should at least support 'create',
+        // 'rename' and 'delete' files and folders.
+        std::optional<QList<ResourceOperationKind>> resourceOperations() const;
+        void setResourceOperations(const QList<ResourceOperationKind> &resourceOperations);
+        void clearResourceOperations() { remove(resourceOperationsKey); }
     };
 
     // Capabilities specific to `WorkspaceEdit`s
-    Utils::optional<WorkspaceEditCapabilities> workspaceEdit() const
+    std::optional<WorkspaceEditCapabilities> workspaceEdit() const
     { return optionalValue<WorkspaceEditCapabilities>(workspaceEditKey); }
     void setWorkspaceEdit(const WorkspaceEditCapabilities &workspaceEdit)
     { insert(workspaceEditKey, workspaceEdit); }
     void clearWorkspaceEdit() { remove(workspaceEditKey); }
 
     // Capabilities specific to the `workspace/didChangeConfiguration` notification.
-    Utils::optional<DynamicRegistrationCapabilities> didChangeConfiguration() const
+    std::optional<DynamicRegistrationCapabilities> didChangeConfiguration() const
     { return optionalValue<DynamicRegistrationCapabilities>(didChangeConfigurationKey); }
     void setDidChangeConfiguration(const DynamicRegistrationCapabilities &didChangeConfiguration)
     { insert(didChangeConfigurationKey, didChangeConfiguration); }
     void clearDidChangeConfiguration() { remove(didChangeConfigurationKey); }
 
     // Capabilities specific to the `workspace/didChangeWatchedFiles` notification.
-    Utils::optional<DynamicRegistrationCapabilities> didChangeWatchedFiles() const
+    std::optional<DynamicRegistrationCapabilities> didChangeWatchedFiles() const
     { return optionalValue<DynamicRegistrationCapabilities>(didChangeWatchedFilesKey); }
     void setDidChangeWatchedFiles(const DynamicRegistrationCapabilities &didChangeWatchedFiles)
     { insert(didChangeWatchedFilesKey, didChangeWatchedFiles); }
     void clearDidChangeWatchedFiles() { remove(didChangeWatchedFilesKey); }
 
     // Specific capabilities for the `SymbolKind` in the `workspace/symbol` request.
-    Utils::optional<SymbolCapabilities> symbol() const
+    std::optional<SymbolCapabilities> symbol() const
     { return optionalValue<SymbolCapabilities>(symbolKey); }
     void setSymbol(const SymbolCapabilities &symbol) { insert(symbolKey, symbol); }
     void clearSymbol() { remove(symbolKey); }
 
     // Capabilities specific to the `workspace/executeCommand` request.
-    Utils::optional<DynamicRegistrationCapabilities> executeCommand() const
+    std::optional<DynamicRegistrationCapabilities> executeCommand() const
     { return optionalValue<DynamicRegistrationCapabilities>(executeCommandKey); }
     void setExecuteCommand(const DynamicRegistrationCapabilities &executeCommand)
     { insert(executeCommandKey, executeCommand); }
     void clearExecuteCommand() { remove(executeCommandKey); }
 
     // The client has support for workspace folders. Since 3.6.0
-    Utils::optional<bool> workspaceFolders() const
+    std::optional<bool> workspaceFolders() const
     { return optionalValue<bool>(workspaceFoldersKey); }
     void setWorkspaceFolders(bool workspaceFolders)
     { insert(workspaceFoldersKey, workspaceFolders); }
     void clearWorkspaceFolders() { remove(workspaceFoldersKey); }
 
     // The client supports `workspace/configuration` requests. Since 3.6.0
-    Utils::optional<bool> configuration() const { return optionalValue<bool>(configurationKey); }
+    std::optional<bool> configuration() const { return optionalValue<bool>(configurationKey); }
     void setConfiguration(bool configuration) { insert(configurationKey, configuration); }
     void clearConfiguration() { remove(configurationKey); }
 
-    Utils::optional<SemanticTokensWorkspaceClientCapabilities> semanticTokens() const
+    std::optional<SemanticTokensWorkspaceClientCapabilities> semanticTokens() const
     { return optionalValue<SemanticTokensWorkspaceClientCapabilities>(semanticTokensKey); }
     void setSemanticTokens(const SemanticTokensWorkspaceClientCapabilities &semanticTokens)
     { insert(semanticTokensKey, semanticTokens); }
@@ -619,14 +629,14 @@ public:
       * in the request specific server capabilities.
       *
       */
-    Utils::optional<bool> workDoneProgress() const
+    std::optional<bool> workDoneProgress() const
     { return optionalValue<bool>(workDoneProgressKey); }
     void setWorkDoneProgress(bool workDoneProgress)
     { insert(workDoneProgressKey, workDoneProgress); }
     void clearWorkDoneProgress() { remove(workDoneProgressKey); }
 
 private:
-    constexpr static const char16_t workDoneProgressKey[] = u"workDoneProgress";
+    constexpr static const char workDoneProgressKey[] = "workDoneProgress";
 };
 
 class LANGUAGESERVERPROTOCOL_EXPORT ClientCapabilities : public JsonObject
@@ -635,21 +645,21 @@ public:
     using JsonObject::JsonObject;
 
     // Workspace specific client capabilities.
-    Utils::optional<WorkspaceClientCapabilities> workspace() const
+    std::optional<WorkspaceClientCapabilities> workspace() const
     { return optionalValue<WorkspaceClientCapabilities>(workspaceKey); }
     void setWorkspace(const WorkspaceClientCapabilities &workspace)
     { insert(workspaceKey, workspace); }
     void clearWorkspace() { remove(workspaceKey); }
 
     // Text document specific client capabilities.
-    Utils::optional<TextDocumentClientCapabilities> textDocument() const
+    std::optional<TextDocumentClientCapabilities> textDocument() const
     { return optionalValue<TextDocumentClientCapabilities>(textDocumentKey); }
     void setTextDocument(const TextDocumentClientCapabilities &textDocument)
     { insert(textDocumentKey, textDocument); }
     void clearTextDocument() { remove(textDocumentKey); }
 
     // Window specific client capabilities.
-    Utils::optional<WindowClientClientCapabilities> window() const
+    std::optional<WindowClientClientCapabilities> window() const
     { return optionalValue<WindowClientClientCapabilities>(windowKey); }
     void setWindow(const WindowClientClientCapabilities &window)
     { insert(windowKey, window); }
