@@ -1,37 +1,15 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
+#include "qmljsdocument.h"
+#include <qmljs/parser/qmljsastfwd_p.h>
 #include <qmljs/qmljs_global.h>
 #include <qmljs/qmljsconstants.h>
 #include <qmljs/qmljsimportdependencies.h>
-#include <qmljs/parser/qmljsastfwd_p.h>
 
 #include <languageutils/fakemetaobject.h>
-#include <utils/porting.h>
 
 #include <QFileInfoList>
 #include <QHash>
@@ -150,7 +128,7 @@ public:
 
     virtual void accept(ValueVisitor *) const = 0;
 
-    virtual bool getSourceLocation(QString *fileName, int *line, int *column) const;
+    virtual bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const;
 };
 
 template <typename RetTy> const RetTy *value_cast(const Value *)
@@ -600,7 +578,7 @@ public:
 
     using ObjectValue::prototype;
     const CppComponentValue *prototype() const;
-    QList<const CppComponentValue *> prototypes() const;
+    const QList<const CppComponentValue *> prototypes() const;
 
     LanguageUtils::FakeMetaObject::ConstPtr metaObject() const;
 
@@ -712,8 +690,8 @@ public:
     static BuiltinObjects loadQmlTypes(const QFileInfoList &qmltypesFiles,
                              QStringList *errors, QStringList *warnings);
 
-    static BuiltinObjects defaultQtObjects;
-    static BuiltinObjects defaultLibraryObjects;
+    static BuiltinObjects &defaultQtObjects();
+    static BuiltinObjects &defaultLibraryObjects();
 
     // parses the contents of a qmltypes file and fills the newObjects map
     static void parseQmlTypeDescriptions(const QByteArray &contents,
@@ -723,6 +701,8 @@ public:
                                          QString *errorMessage,
                                          QString *warningMessage,
                                          const QString &fileName);
+
+    static std::function<void()> defaultObjectsInitializer;
 };
 
 class QMLJS_EXPORT FakeMetaObjectWithOrigin
@@ -735,7 +715,7 @@ public:
     bool operator ==(const FakeMetaObjectWithOrigin &o) const;
 };
 
-QMLJS_EXPORT Utils::QHashValueType qHash(const FakeMetaObjectWithOrigin &fmoo);
+QMLJS_EXPORT size_t qHash(const FakeMetaObjectWithOrigin &fmoo);
 
 class QMLJS_EXPORT CppQmlTypes
 {
@@ -891,7 +871,7 @@ public:
     const AST::PatternElement *ast() const;
 private:
     const Value *value(ReferenceContext *referenceContext) const override;
-    bool getSourceLocation(QString *fileName, int *line, int *column) const override;
+    bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const override;
 };
 
 class QMLJS_EXPORT ASTFunctionValue: public FunctionValue
@@ -912,7 +892,7 @@ public:
     bool isVariadic() const override;
     const ASTFunctionValue *asAstFunctionValue() const override;
 
-    bool getSourceLocation(QString *fileName, int *line, int *column) const override;
+    bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const override;
 };
 
 class QMLJS_EXPORT ASTPropertyReference: public Reference
@@ -930,7 +910,7 @@ public:
     AST::UiPublicMember *ast() const { return m_ast; }
     QString onChangedSlotName() const { return m_onChangedSlotName; }
 
-    bool getSourceLocation(QString *fileName, int *line, int *column) const override;
+    bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const override;
 
 private:
     const Value *value(ReferenceContext *referenceContext) const override;
@@ -959,7 +939,7 @@ public:
     QString argumentName(int index) const override;
 
     // Value interface
-    bool getSourceLocation(QString *fileName, int *line, int *column) const override;
+    bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const override;
 };
 
 class QMLJS_EXPORT ASTObjectValue: public ObjectValue
@@ -980,7 +960,7 @@ public:
 
     const ASTObjectValue *asAstObjectValue() const override;
 
-    bool getSourceLocation(QString *fileName, int *line, int *column) const override;
+    bool getSourceLocation(Utils::FilePath *fileName, int *line, int *column) const override;
     void processMembers(MemberProcessor *processor) const override;
 
     QString defaultPropertyName() const;
@@ -997,9 +977,11 @@ public:
 
     static ImportInfo moduleImport(QString uri, LanguageUtils::ComponentVersion version,
                                    const QString &as, AST::UiImport *ast = nullptr);
-    static ImportInfo pathImport(const QString &docPath, const QString &path,
+    static ImportInfo pathImport(const Utils::FilePath &docPath,
+                                 const QString &path,
                                  LanguageUtils::ComponentVersion version,
-                                 const QString &as, AST::UiImport *ast = nullptr);
+                                 const QString &as,
+                                 AST::UiImport *ast = nullptr);
     static ImportInfo invalidImport(AST::UiImport *ast = nullptr);
     static ImportInfo implicitDirectoryImport(const QString &directory);
     static ImportInfo qrcDirectoryImport(const QString &directory);
@@ -1041,7 +1023,7 @@ public:
     ImportInfo info;
     DependencyInfo::ConstPtr deps;
     // uri imports: path to library, else empty
-    QString libraryPath;
+    Utils::FilePath libraryPath;
     // whether the import succeeded
     bool valid;
     mutable bool used;
@@ -1129,12 +1111,25 @@ class QMLJS_EXPORT CustomImportsProvider : public QObject
 {
     Q_OBJECT
 public:
+    typedef QHash<const Document *, QSharedPointer<const Imports>> ImportsPerDocument;
     explicit CustomImportsProvider(QObject *parent = nullptr);
     virtual ~CustomImportsProvider();
 
     static const QList<CustomImportsProvider *> allProviders();
 
-    virtual QList<Import> imports(ValueOwner *valueOwner, const Document *context) const = 0;
+    virtual QList<Import> imports(ValueOwner *valueOwner,
+                                  const Document *context,
+                                  Snapshot *snapshot = nullptr) const = 0;
+    virtual void loadBuiltins([[maybe_unused]] ImportsPerDocument *importsPerDocument,
+                              [[maybe_unused]] Imports *imports,
+                              [[maybe_unused]] const Document *context,
+                              [[maybe_unused]] ValueOwner *valueOwner,
+                              [[maybe_unused]] Snapshot *snapshot) {}
+    virtual Utils::FilePaths prioritizeImportPaths([[maybe_unused]] const Document *context,
+                                                   const Utils::FilePaths &importPaths)
+    {
+        return importPaths;
+    }
 };
 
 } // namespace QmlJS
