@@ -5,11 +5,12 @@
 
 #include "texteditor_global.h"
 
+#include <utils/store.h>
+
 #include <QObject>
 
 QT_BEGIN_NAMESPACE
 class QVariant;
-class QSettings;
 QT_END_NAMESPACE
 
 namespace TextEditor {
@@ -40,6 +41,9 @@ public:
     bool isTemporarilyReadOnly() const;
     void setTemporarilyReadOnly(bool on);
 
+    bool isAdditionalTabDisabled() const;
+    void setIsAdditionalTabDisabled(bool on);
+
     void setTabSettings(const TabSettings &settings);
     TabSettings tabSettings() const;
     TabSettings currentTabSettings() const;
@@ -60,13 +64,13 @@ public:
     QByteArray currentDelegateId() const;
     void setCurrentDelegate(const QByteArray &id);
 
-    void setSettingsSuffix(const QString &suffix);
-    void toSettings(const QString &category, QSettings *s) const;
-    void fromSettings(const QString &category, QSettings *s);
+    void setSettingsSuffix(const Utils::Key &suffix);
+    void toSettings(const Utils::Key &category) const;
+    void fromSettings(const Utils::Key &category);
 
     // make below 2 protected?
-    virtual QVariantMap toMap() const;
-    virtual void fromMap(const QVariantMap &map);
+    virtual Utils::Store toMap() const;
+    virtual void fromMap(const Utils::Store &map);
 
 signals:
     void tabSettingsChanged(const TextEditor::TabSettings &settings);
